@@ -1,15 +1,27 @@
+import pytorch_quik.args
 import pytorch_quik.ddp
+import pytorch_quik.io
 import pytorch_quik.metrics
 import pytorch_quik.tensor
 import pytorch_quik.transform
 import pytorch_quik.travel
 import pytorch_quik.utils
 
-__all__ = ["ddp", "metrics", "tensor", "transform", "travel", "utils"]
-__version__ = "0.0.4"
+__all__ = [
+    "args",
+    "io",
+    "ddp",
+    "metrics",
+    "tensor",
+    "transform",
+    "travel",
+    "utils",
+]
+__version__ = "0.1.0"
 
 try:
     import pytorch_quik.bert
+
     __all__.append("bert")
 except ImportError:
     print("skipping bert functions")
